# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/card/v1/double.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.card.v1 import common_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/card/v1/double.proto\x12\x14\x62ilibili.app.card.v1\x1a!bilibili/app/card/v1/common.proto\"\xc3\x01\n\x0b\x44oubleCards\x12<\n\x0esmall_cover_v2\x18\x01 \x01(\x0b\x32\".bilibili.app.card.v1.SmallCoverV2H\x00\x12\x34\n\none_pic_v2\x18\x02 \x01(\x0b\x32\x1e.bilibili.app.card.v1.OnePicV2H\x00\x12\x38\n\x0cthree_pic_v2\x18\x03 \x01(\x0b\x32 .bilibili.app.card.v1.ThreePicV2H\x00\x42\x06\n\x04\x43\x61rd\"\xf6\x04\n\x0cSmallCoverV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\tcover_gif\x18\x02 \x01(\t\x12\x12\n\ncover_blur\x18\x03 \x01(\x05\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x05 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x06 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x07 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\x08 \x01(\t\x12\x18\n\x10\x63over_right_icon\x18\t \x01(\x05\x12$\n\x1c\x63over_right_background_color\x18\n \x01(\t\x12\x10\n\x08subtitle\x18\x0b \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x0c \x01(\t\x12\x13\n\x0brcmd_reason\x18\r \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0e \x01(\t\x12,\n\x06\x61vatar\x18\x0f \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12\x15\n\rofficial_icon\x18\x10 \x01(\x05\x12\x10\n\x08\x63\x61n_play\x18\x11 \x01(\x05\x12<\n\x11rcmd_reason_style\x18\x12 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12?\n\x14rcmd_reason_style_v2\x18\x13 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x35\n\x0blike_button\x18\x14 \x01(\x0b\x32 .bilibili.app.card.v1.LikeButton\"\xc3\x02\n\x0cSmallCoverV3\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12,\n\x06\x61vatar\x18\x02 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12\x17\n\x0f\x63over_left_text\x18\x03 \x01(\t\x12\x38\n\x12\x63over_right_button\x18\x04 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Button\x12\x13\n\x0brcmd_reason\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\x15\n\rofficial_icon\x18\x07 \x01(\x05\x12\x10\n\x08\x63\x61n_play\x18\x08 \x01(\x05\x12<\n\x11rcmd_reason_style\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"e\n\rMiddleCoverV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\r\n\x05ratio\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x04 \x01(\t\"\xbe\x03\n\x0cLargeCoverV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12,\n\x06\x61vatar\x18\x02 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12\r\n\x05\x62\x61\x64ge\x18\x03 \x01(\t\x12\x38\n\x12\x63over_right_button\x18\x04 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Button\x12\x19\n\x11\x63over_left_text_1\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x06 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x07 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x08 \x01(\x05\x12\x13\n\x0brcmd_reason\x18\t \x01(\t\x12\x15\n\rofficial_icon\x18\n \x01(\x05\x12\x10\n\x08\x63\x61n_play\x18\x0b \x01(\x05\x12<\n\x11rcmd_reason_style\x18\x0c \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x10\n\x08show_top\x18\r \x01(\x05\x12\x13\n\x0bshow_bottom\x18\x0e \x01(\x05\"\xa6\x01\n\x0bThreeItemV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x12\n\ntitle_icon\x18\x02 \x01(\x05\x12\x10\n\x08more_uri\x18\x03 \x01(\t\x12\x11\n\tmore_text\x18\x04 \x01(\t\x12\x34\n\x05items\x18\x05 \x03(\x0b\x32%.bilibili.app.card.v1.ThreeItemV2Item\"\xb7\x01\n\x0fThreeItemV2Item\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x17\n\x0f\x63over_left_icon\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65sc_text_1\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_icon_1\x18\x04 \x01(\x05\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65sc_icon_2\x18\x06 \x01(\x05\x12\r\n\x05\x62\x61\x64ge\x18\x07 \x01(\t\"\x8e\x01\n\x0cSmallCoverV4\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x13\n\x0b\x63over_badge\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x18\n\x10title_right_text\x18\x04 \x01(\t\x12\x17\n\x0ftitle_right_pic\x18\x05 \x01(\x05\"i\n\tTwoItemV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.bilibili.app.card.v1.TwoItemV2Item\"~\n\rTwoItemV2Item\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\r\n\x05\x62\x61\x64ge\x18\x02 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x04 \x01(\x05\"\x8c\x01\n\tMultiItem\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x10\n\x08more_uri\x18\x02 \x01(\t\x12\x11\n\tmore_text\x18\x03 \x01(\t\x12\x30\n\x05items\x18\x04 \x03(\x0b\x32!.bilibili.app.card.v1.DoubleCards\"\xdc\x03\n\nThreePicV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x12\n\nleft_cover\x18\x02 \x01(\t\x12\x15\n\rright_cover_1\x18\x03 \x01(\t\x12\x15\n\rright_cover_2\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x06 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x07 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x08 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\t \x01(\t\x12\x18\n\x10\x63over_right_icon\x18\n \x01(\x05\x12$\n\x1c\x63over_right_background_color\x18\x0b \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x0c \x01(\t\x12\x13\n\x0brcmd_reason\x18\r \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0e \x01(\t\x12,\n\x06\x61vatar\x18\x0f \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12<\n\x11rcmd_reason_style\x18\x10 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\xd4\x02\n\x08OnePicV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x19\n\x11\x63over_left_icon_1\x18\x02 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x03 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_right_icon\x18\x05 \x01(\x05\x12$\n\x1c\x63over_right_background_color\x18\x06 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x07 \x01(\t\x12\x13\n\x0brcmd_reason\x18\x08 \x01(\t\x12,\n\x06\x61vatar\x18\t \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12<\n\x11rcmd_reason_style\x18\n \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\xab\x03\n\x0cLargeCoverV3\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\tcover_gif\x18\x02 \x01(\t\x12,\n\x06\x61vatar\x18\x03 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12@\n\x15top_rcmd_reason_style\x18\x04 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x43\n\x18\x62ottom_rcmd_reason_style\x18\x05 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x19\n\x11\x63over_left_text_1\x18\x06 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x07 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x08 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\t \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\n \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0b \x01(\t\x12\x15\n\rofficial_icon\x18\x0c \x01(\x05\"\x8b\x03\n\nThreePicV3\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x12\n\nleft_cover\x18\x02 \x01(\t\x12\x15\n\rright_cover_1\x18\x03 \x01(\t\x12\x15\n\rright_cover_2\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x06 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x07 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x08 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\t \x01(\t\x12\x18\n\x10\x63over_right_icon\x18\n \x01(\x05\x12$\n\x1c\x63over_right_background_color\x18\x0b \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x0c \x01(\t\x12<\n\x11rcmd_reason_style\x18\r \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\x91\x02\n\x08OnePicV3\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x19\n\x11\x63over_left_text_1\x18\x02 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x03 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_right_icon\x18\x05 \x01(\x05\x12$\n\x1c\x63over_right_background_color\x18\x06 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x07 \x01(\t\x12<\n\x11rcmd_reason_style\x18\x08 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"F\n\x0cSmallCoverV7\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"\xdb\x03\n\x0cSmallCoverV9\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x19\n\x11\x63over_left_text_1\x18\x02 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x03 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x05 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\x06 \x01(\t\x12\x18\n\x10\x63over_right_icon\x18\x07 \x01(\x05\x12\x10\n\x08\x63\x61n_play\x18\x08 \x01(\x05\x12<\n\x11rcmd_reason_style\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12$\n\x02up\x18\n \x01(\x0b\x32\x18.bilibili.app.card.v1.Up\x12\x41\n\x16left_cover_badge_style\x18\x0b \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12H\n\x1dleft_bottom_rcmd_reason_style\x18\x0c \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\xe3\x02\n\x14SmallCoverConvergeV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x19\n\x11\x63over_left_text_1\x18\x02 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x03 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x05 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\x06 \x01(\t\x12\x1c\n\x14\x63over_right_top_text\x18\x07 \x01(\t\x12<\n\x11rcmd_reason_style\x18\x08 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12?\n\x14rcmd_reason_style_v2\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\xc0\x01\n\x13SmallChannelSpecial\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x10\n\x08\x62g_cover\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65sc_1\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x65sc_2\x18\x04 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x05 \x01(\t\x12>\n\x13rcmd_reason_style_2\x18\x06 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyleb\x06proto3')



_DOUBLECARDS = DESCRIPTOR.message_types_by_name['DoubleCards']
_SMALLCOVERV2 = DESCRIPTOR.message_types_by_name['SmallCoverV2']
_SMALLCOVERV3 = DESCRIPTOR.message_types_by_name['SmallCoverV3']
_MIDDLECOVERV2 = DESCRIPTOR.message_types_by_name['MiddleCoverV2']
_LARGECOVERV2 = DESCRIPTOR.message_types_by_name['LargeCoverV2']
_THREEITEMV2 = DESCRIPTOR.message_types_by_name['ThreeItemV2']
_THREEITEMV2ITEM = DESCRIPTOR.message_types_by_name['ThreeItemV2Item']
_SMALLCOVERV4 = DESCRIPTOR.message_types_by_name['SmallCoverV4']
_TWOITEMV2 = DESCRIPTOR.message_types_by_name['TwoItemV2']
_TWOITEMV2ITEM = DESCRIPTOR.message_types_by_name['TwoItemV2Item']
_MULTIITEM = DESCRIPTOR.message_types_by_name['MultiItem']
_THREEPICV2 = DESCRIPTOR.message_types_by_name['ThreePicV2']
_ONEPICV2 = DESCRIPTOR.message_types_by_name['OnePicV2']
_LARGECOVERV3 = DESCRIPTOR.message_types_by_name['LargeCoverV3']
_THREEPICV3 = DESCRIPTOR.message_types_by_name['ThreePicV3']
_ONEPICV3 = DESCRIPTOR.message_types_by_name['OnePicV3']
_SMALLCOVERV7 = DESCRIPTOR.message_types_by_name['SmallCoverV7']
_SMALLCOVERV9 = DESCRIPTOR.message_types_by_name['SmallCoverV9']
_SMALLCOVERCONVERGEV2 = DESCRIPTOR.message_types_by_name['SmallCoverConvergeV2']
_SMALLCHANNELSPECIAL = DESCRIPTOR.message_types_by_name['SmallChannelSpecial']
DoubleCards = _reflection.GeneratedProtocolMessageType('DoubleCards', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLECARDS,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.DoubleCards)
  })
_sym_db.RegisterMessage(DoubleCards)

SmallCoverV2 = _reflection.GeneratedProtocolMessageType('SmallCoverV2', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverV2)
  })
_sym_db.RegisterMessage(SmallCoverV2)

SmallCoverV3 = _reflection.GeneratedProtocolMessageType('SmallCoverV3', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERV3,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverV3)
  })
_sym_db.RegisterMessage(SmallCoverV3)

MiddleCoverV2 = _reflection.GeneratedProtocolMessageType('MiddleCoverV2', (_message.Message,), {
  'DESCRIPTOR' : _MIDDLECOVERV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.MiddleCoverV2)
  })
_sym_db.RegisterMessage(MiddleCoverV2)

LargeCoverV2 = _reflection.GeneratedProtocolMessageType('LargeCoverV2', (_message.Message,), {
  'DESCRIPTOR' : _LARGECOVERV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.LargeCoverV2)
  })
_sym_db.RegisterMessage(LargeCoverV2)

ThreeItemV2 = _reflection.GeneratedProtocolMessageType('ThreeItemV2', (_message.Message,), {
  'DESCRIPTOR' : _THREEITEMV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.ThreeItemV2)
  })
_sym_db.RegisterMessage(ThreeItemV2)

ThreeItemV2Item = _reflection.GeneratedProtocolMessageType('ThreeItemV2Item', (_message.Message,), {
  'DESCRIPTOR' : _THREEITEMV2ITEM,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.ThreeItemV2Item)
  })
_sym_db.RegisterMessage(ThreeItemV2Item)

SmallCoverV4 = _reflection.GeneratedProtocolMessageType('SmallCoverV4', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERV4,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverV4)
  })
_sym_db.RegisterMessage(SmallCoverV4)

TwoItemV2 = _reflection.GeneratedProtocolMessageType('TwoItemV2', (_message.Message,), {
  'DESCRIPTOR' : _TWOITEMV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.TwoItemV2)
  })
_sym_db.RegisterMessage(TwoItemV2)

TwoItemV2Item = _reflection.GeneratedProtocolMessageType('TwoItemV2Item', (_message.Message,), {
  'DESCRIPTOR' : _TWOITEMV2ITEM,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.TwoItemV2Item)
  })
_sym_db.RegisterMessage(TwoItemV2Item)

MultiItem = _reflection.GeneratedProtocolMessageType('MultiItem', (_message.Message,), {
  'DESCRIPTOR' : _MULTIITEM,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.MultiItem)
  })
_sym_db.RegisterMessage(MultiItem)

ThreePicV2 = _reflection.GeneratedProtocolMessageType('ThreePicV2', (_message.Message,), {
  'DESCRIPTOR' : _THREEPICV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.ThreePicV2)
  })
_sym_db.RegisterMessage(ThreePicV2)

OnePicV2 = _reflection.GeneratedProtocolMessageType('OnePicV2', (_message.Message,), {
  'DESCRIPTOR' : _ONEPICV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.OnePicV2)
  })
_sym_db.RegisterMessage(OnePicV2)

LargeCoverV3 = _reflection.GeneratedProtocolMessageType('LargeCoverV3', (_message.Message,), {
  'DESCRIPTOR' : _LARGECOVERV3,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.LargeCoverV3)
  })
_sym_db.RegisterMessage(LargeCoverV3)

ThreePicV3 = _reflection.GeneratedProtocolMessageType('ThreePicV3', (_message.Message,), {
  'DESCRIPTOR' : _THREEPICV3,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.ThreePicV3)
  })
_sym_db.RegisterMessage(ThreePicV3)

OnePicV3 = _reflection.GeneratedProtocolMessageType('OnePicV3', (_message.Message,), {
  'DESCRIPTOR' : _ONEPICV3,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.OnePicV3)
  })
_sym_db.RegisterMessage(OnePicV3)

SmallCoverV7 = _reflection.GeneratedProtocolMessageType('SmallCoverV7', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERV7,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverV7)
  })
_sym_db.RegisterMessage(SmallCoverV7)

SmallCoverV9 = _reflection.GeneratedProtocolMessageType('SmallCoverV9', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERV9,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverV9)
  })
_sym_db.RegisterMessage(SmallCoverV9)

SmallCoverConvergeV2 = _reflection.GeneratedProtocolMessageType('SmallCoverConvergeV2', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERCONVERGEV2,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverConvergeV2)
  })
_sym_db.RegisterMessage(SmallCoverConvergeV2)

SmallChannelSpecial = _reflection.GeneratedProtocolMessageType('SmallChannelSpecial', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCHANNELSPECIAL,
  '__module__' : 'bilibili.app.card.v1.double_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallChannelSpecial)
  })
_sym_db.RegisterMessage(SmallChannelSpecial)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOUBLECARDS._serialized_start=95
  _DOUBLECARDS._serialized_end=290
  _SMALLCOVERV2._serialized_start=293
  _SMALLCOVERV2._serialized_end=923
  _SMALLCOVERV3._serialized_start=926
  _SMALLCOVERV3._serialized_end=1249
  _MIDDLECOVERV2._serialized_start=1251
  _MIDDLECOVERV2._serialized_end=1352
  _LARGECOVERV2._serialized_start=1355
  _LARGECOVERV2._serialized_end=1801
  _THREEITEMV2._serialized_start=1804
  _THREEITEMV2._serialized_end=1970
  _THREEITEMV2ITEM._serialized_start=1973
  _THREEITEMV2ITEM._serialized_end=2156
  _SMALLCOVERV4._serialized_start=2159
  _SMALLCOVERV4._serialized_end=2301
  _TWOITEMV2._serialized_start=2303
  _TWOITEMV2._serialized_end=2408
  _TWOITEMV2ITEM._serialized_start=2410
  _TWOITEMV2ITEM._serialized_end=2536
  _MULTIITEM._serialized_start=2539
  _MULTIITEM._serialized_end=2679
  _THREEPICV2._serialized_start=2682
  _THREEPICV2._serialized_end=3158
  _ONEPICV2._serialized_start=3161
  _ONEPICV2._serialized_end=3501
  _LARGECOVERV3._serialized_start=3504
  _LARGECOVERV3._serialized_end=3931
  _THREEPICV3._serialized_start=3934
  _THREEPICV3._serialized_end=4329
  _ONEPICV3._serialized_start=4332
  _ONEPICV3._serialized_end=4605
  _SMALLCOVERV7._serialized_start=4607
  _SMALLCOVERV7._serialized_end=4677
  _SMALLCOVERV9._serialized_start=4680
  _SMALLCOVERV9._serialized_end=5155
  _SMALLCOVERCONVERGEV2._serialized_start=5158
  _SMALLCOVERCONVERGEV2._serialized_end=5513
  _SMALLCHANNELSPECIAL._serialized_start=5516
  _SMALLCHANNELSPECIAL._serialized_end=5708
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Metadata(google.protobuf.message.Message):
    """请求元数据
    gRPC头部:x-bili-metadata-bin
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACCESS_KEY_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    access_key: typing.Text
    """登录Token"""

    mobi_app: typing.Text
    """包类型"""

    device: typing.Text
    """运行设备"""

    build: builtins.int
    """构建id"""

    channel: typing.Text
    """渠道"""

    buvid: typing.Text
    """设备buvid"""

    platform: typing.Text
    """平台类型"""

    def __init__(self,
        *,
        access_key: typing.Text = ...,
        mobi_app: typing.Text = ...,
        device: typing.Text = ...,
        build: builtins.int = ...,
        channel: typing.Text = ...,
        buvid: typing.Text = ...,
        platform: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key",b"access_key","build",b"build","buvid",b"buvid","channel",b"channel","device",b"device","mobi_app",b"mobi_app","platform",b"platform"]) -> None: ...
global___Metadata = Metadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EntranceReq(google.protobuf.message.Message):
    """活动入口-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___EntranceReq = EntranceReq

class EntranceReply(google.protobuf.message.Message):
    """活动入口-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ANIMATE_ICON_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """展示图标"""

    name: typing.Text
    """活动名称"""

    url: typing.Text
    """活动跳转链接"""

    @property
    def animate_icon(self) -> global___AnimateIcon:
        """动画效果"""
        pass
    def __init__(self,
        *,
        icon: typing.Text = ...,
        name: typing.Text = ...,
        url: typing.Text = ...,
        animate_icon: typing.Optional[global___AnimateIcon] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animate_icon",b"animate_icon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animate_icon",b"animate_icon","icon",b"icon","name",b"name","url",b"url"]) -> None: ...
global___EntranceReply = EntranceReply

class WindowReq(google.protobuf.message.Message):
    """首页弹窗-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___WindowReq = WindowReq

class WindowReply(google.protobuf.message.Message):
    """首页弹窗-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    REPORT_DATA_FIELD_NUMBER: builtins.int
    type: builtins.int
    """弹窗类型
    0:弹窗 1:普通页面
    """

    url: typing.Text
    """跳转链接"""

    report_data: typing.Text
    """上报数据字段"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        url: typing.Text = ...,
        report_data: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["report_data",b"report_data","type",b"type","url",b"url"]) -> None: ...
global___WindowReply = WindowReply

class AnimateIcon(google.protobuf.message.Message):
    """动画效果"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """icon文件"""

    json: typing.Text
    """动效json文件"""

    def __init__(self,
        *,
        icon: typing.Text = ...,
        json: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","json",b"json"]) -> None: ...
global___AnimateIcon = AnimateIcon



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/live/app/room/v1/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/live/app/room/v1/room.proto\x12\x19\x62ilibili.live.app.room.v1\"#\n\x10GetStudioListReq\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\"\x86\x04\n\x11GetStudioListResp\x12\x0e\n\x06status\x18\x01 \x01(\x03\x12N\n\x0bmaster_list\x18\x02 \x03(\x0b\x32\x39.bilibili.live.app.room.v1.GetStudioListResp.StudioMaster\x1a\x94\x01\n\x08Pendants\x12\x43\n\x05\x66rame\x18\x01 \x01(\x0b\x32\x34.bilibili.live.app.room.v1.GetStudioListResp.Pendant\x12\x43\n\x05\x62\x61\x64ge\x18\x02 \x01(\x0b\x32\x34.bilibili.live.app.room.v1.GetStudioListResp.Pendant\x1a\x46\n\x07Pendant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\x03\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x1a\xb1\x01\n\x0cStudioMaster\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\r\n\x05uname\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12G\n\x08pendants\x18\x05 \x01(\x0b\x32\x35.bilibili.live.app.room.v1.GetStudioListResp.Pendants\x12\x0b\n\x03tag\x18\x06 \x01(\t\x12\x10\n\x08tag_type\x18\x07 \x01(\x03\x32x\n\nStudioList\x12j\n\rGetStudioList\x12+.bilibili.live.app.room.v1.GetStudioListReq\x1a,.bilibili.live.app.room.v1.GetStudioListRespb\x06proto3')



_GETSTUDIOLISTREQ = DESCRIPTOR.message_types_by_name['GetStudioListReq']
_GETSTUDIOLISTRESP = DESCRIPTOR.message_types_by_name['GetStudioListResp']
_GETSTUDIOLISTRESP_PENDANTS = _GETSTUDIOLISTRESP.nested_types_by_name['Pendants']
_GETSTUDIOLISTRESP_PENDANT = _GETSTUDIOLISTRESP.nested_types_by_name['Pendant']
_GETSTUDIOLISTRESP_STUDIOMASTER = _GETSTUDIOLISTRESP.nested_types_by_name['StudioMaster']
GetStudioListReq = _reflection.GeneratedProtocolMessageType('GetStudioListReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDIOLISTREQ,
  '__module__' : 'bilibili.live.app.room.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.app.room.v1.GetStudioListReq)
  })
_sym_db.RegisterMessage(GetStudioListReq)

GetStudioListResp = _reflection.GeneratedProtocolMessageType('GetStudioListResp', (_message.Message,), {

  'Pendants' : _reflection.GeneratedProtocolMessageType('Pendants', (_message.Message,), {
    'DESCRIPTOR' : _GETSTUDIOLISTRESP_PENDANTS,
    '__module__' : 'bilibili.live.app.room.v1.room_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.live.app.room.v1.GetStudioListResp.Pendants)
    })
  ,

  'Pendant' : _reflection.GeneratedProtocolMessageType('Pendant', (_message.Message,), {
    'DESCRIPTOR' : _GETSTUDIOLISTRESP_PENDANT,
    '__module__' : 'bilibili.live.app.room.v1.room_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.live.app.room.v1.GetStudioListResp.Pendant)
    })
  ,

  'StudioMaster' : _reflection.GeneratedProtocolMessageType('StudioMaster', (_message.Message,), {
    'DESCRIPTOR' : _GETSTUDIOLISTRESP_STUDIOMASTER,
    '__module__' : 'bilibili.live.app.room.v1.room_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.live.app.room.v1.GetStudioListResp.StudioMaster)
    })
  ,
  'DESCRIPTOR' : _GETSTUDIOLISTRESP,
  '__module__' : 'bilibili.live.app.room.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.app.room.v1.GetStudioListResp)
  })
_sym_db.RegisterMessage(GetStudioListResp)
_sym_db.RegisterMessage(GetStudioListResp.Pendants)
_sym_db.RegisterMessage(GetStudioListResp.Pendant)
_sym_db.RegisterMessage(GetStudioListResp.StudioMaster)

_STUDIOLIST = DESCRIPTOR.services_by_name['StudioList']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETSTUDIOLISTREQ._serialized_start=67
  _GETSTUDIOLISTREQ._serialized_end=102
  _GETSTUDIOLISTRESP._serialized_start=105
  _GETSTUDIOLISTRESP._serialized_end=623
  _GETSTUDIOLISTRESP_PENDANTS._serialized_start=223
  _GETSTUDIOLISTRESP_PENDANTS._serialized_end=371
  _GETSTUDIOLISTRESP_PENDANT._serialized_start=373
  _GETSTUDIOLISTRESP_PENDANT._serialized_end=443
  _GETSTUDIOLISTRESP_STUDIOMASTER._serialized_start=446
  _GETSTUDIOLISTRESP_STUDIOMASTER._serialized_end=623
  _STUDIOLIST._serialized_start=625
  _STUDIOLIST._serialized_end=745
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/splash/v1/splash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#bilibili/app/splash/v1/splash.proto\x12\x16\x62ilibili.app.splash.v1\x1a\x19google/protobuf/any.proto\"8\n\x0cShowStrategy\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05stime\x18\x02 \x01(\x03\x12\r\n\x05\x65time\x18\x03 \x01(\x03\"\x91\x06\n\nSplashItem\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x11\n\tcard_type\x18\x03 \x01(\x05\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\x12\x12\n\nbegin_time\x18\x05 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x03\x12\r\n\x05thumb\x18\x07 \x01(\t\x12\x0c\n\x04hash\x18\x08 \x01(\t\x12\x10\n\x08logo_url\x18\t \x01(\t\x12\x11\n\tlogo_hash\x18\n \x01(\t\x12\x11\n\tvideo_url\x18\x0b \x01(\t\x12\x12\n\nvideo_hash\x18\x0c \x01(\t\x12\x13\n\x0bvideo_width\x18\r \x01(\x05\x12\x14\n\x0cvideo_height\x18\x0e \x01(\x05\x12\x0e\n\x06schema\x18\x0f \x01(\t\x12\x14\n\x0cschema_title\x18\x10 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x11 \x01(\t\x12\x1f\n\x17schema_callup_whiteList\x18\x12 \x03(\t\x12\x0c\n\x04skip\x18\x13 \x01(\x05\x12\x0b\n\x03uri\x18\x14 \x01(\t\x12\x11\n\turi_title\x18\x15 \x01(\t\x12\x0e\n\x06source\x18\x16 \x01(\x05\x12\x0f\n\x07\x63m_mark\x18\x17 \x01(\x05\x12\r\n\x05\x61\x64_cb\x18\x18 \x01(\t\x12\x13\n\x0bresource_id\x18\x19 \x01(\x03\x12\x12\n\nrequest_id\x18\x1a \x01(\t\x12\x11\n\tclient_ip\x18\x1b \x01(\t\x12\r\n\x05is_ad\x18\x1c \x01(\x08\x12\x11\n\tis_ad_loc\x18\x1d \x01(\x08\x12#\n\x05\x65xtra\x18\x1e \x01(\x0b\x32\x14.google.protobuf.Any\x12\x12\n\ncard_index\x18\x1f \x01(\x03\x12\x13\n\x0bserver_type\x18  \x01(\x03\x12\r\n\x05index\x18! \x01(\x03\x12\x11\n\tclick_url\x18\" \x01(\t\x12\x10\n\x08show_url\x18# \x01(\t\x12\x13\n\x0btime_target\x18$ \x01(\x05\x12\x12\n\nencryption\x18% \x01(\x05\x12\x1b\n\x13\x65nable_pre_download\x18& \x01(\x08\x12\"\n\x1a\x65nable_background_download\x18\' \x01(\x08\"\xb2\x01\n\x0bSplashReply\x12\x10\n\x08max_time\x18\x01 \x01(\x05\x12\x14\n\x0cmin_interval\x18\x02 \x01(\x05\x12\x15\n\rpull_interval\x18\x03 \x01(\x05\x12\x30\n\x04list\x18\x04 \x03(\x0b\x32\".bilibili.app.splash.v1.SplashItem\x12\x32\n\x04show\x18\x05 \x03(\x0b\x32$.bilibili.app.splash.v1.ShowStrategy\"\\\n\tSplashReq\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05\x62irth\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t2X\n\x06Splash\x12N\n\x04List\x12!.bilibili.app.splash.v1.SplashReq\x1a#.bilibili.app.splash.v1.SplashReplyb\x06proto3')



_SHOWSTRATEGY = DESCRIPTOR.message_types_by_name['ShowStrategy']
_SPLASHITEM = DESCRIPTOR.message_types_by_name['SplashItem']
_SPLASHREPLY = DESCRIPTOR.message_types_by_name['SplashReply']
_SPLASHREQ = DESCRIPTOR.message_types_by_name['SplashReq']
ShowStrategy = _reflection.GeneratedProtocolMessageType('ShowStrategy', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSTRATEGY,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.ShowStrategy)
  })
_sym_db.RegisterMessage(ShowStrategy)

SplashItem = _reflection.GeneratedProtocolMessageType('SplashItem', (_message.Message,), {
  'DESCRIPTOR' : _SPLASHITEM,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.SplashItem)
  })
_sym_db.RegisterMessage(SplashItem)

SplashReply = _reflection.GeneratedProtocolMessageType('SplashReply', (_message.Message,), {
  'DESCRIPTOR' : _SPLASHREPLY,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.SplashReply)
  })
_sym_db.RegisterMessage(SplashReply)

SplashReq = _reflection.GeneratedProtocolMessageType('SplashReq', (_message.Message,), {
  'DESCRIPTOR' : _SPLASHREQ,
  '__module__' : 'bilibili.app.splash.v1.splash_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.splash.v1.SplashReq)
  })
_sym_db.RegisterMessage(SplashReq)

_SPLASH = DESCRIPTOR.services_by_name['Splash']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHOWSTRATEGY._serialized_start=90
  _SHOWSTRATEGY._serialized_end=146
  _SPLASHITEM._serialized_start=149
  _SPLASHITEM._serialized_end=934
  _SPLASHREPLY._serialized_start=937
  _SPLASHREPLY._serialized_end=1115
  _SPLASHREQ._serialized_start=1117
  _SPLASHREQ._serialized_end=1209
  _SPLASH._serialized_start=1211
  _SPLASH._serialized_end=1299
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.card.v1.single_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Card(google.protobuf.message.Message):
    """卡片信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SMALL_COVER_V5_FIELD_NUMBER: builtins.int
    LARGE_COVER_V1_FIELD_NUMBER: builtins.int
    THREE_ITEM_ALL_V2_FIELD_NUMBER: builtins.int
    THREE_ITEM_V1_FIELD_NUMBER: builtins.int
    HOT_TOPIC_FIELD_NUMBER: builtins.int
    THREE_ITEM_H_V5_FIELD_NUMBER: builtins.int
    MIDDLE_COVER_V3_FIELD_NUMBER: builtins.int
    LARGE_COVER_V4_FIELD_NUMBER: builtins.int
    POPULAR_TOP_ENTRANCE_FIELD_NUMBER: builtins.int
    RCMD_ONE_ITEM_FIELD_NUMBER: builtins.int
    @property
    def small_cover_v5(self) -> bilibili.app.card.v1.single_pb2.SmallCoverV5:
        """小封面条目"""
        pass
    @property
    def large_cover_v1(self) -> bilibili.app.card.v1.single_pb2.LargeCoverV1:
        """"""
        pass
    @property
    def three_item_all_v2(self) -> bilibili.app.card.v1.single_pb2.ThreeItemAllV2:
        """"""
        pass
    @property
    def three_item_v1(self) -> bilibili.app.card.v1.single_pb2.ThreeItemV1:
        """"""
        pass
    @property
    def hot_topic(self) -> bilibili.app.card.v1.single_pb2.HotTopic:
        """"""
        pass
    @property
    def three_item_h_v5(self) -> bilibili.app.card.v1.single_pb2.DynamicHot:
        """"""
        pass
    @property
    def middle_cover_v3(self) -> bilibili.app.card.v1.single_pb2.MiddleCoverV3:
        """"""
        pass
    @property
    def large_cover_v4(self) -> bilibili.app.card.v1.single_pb2.LargeCoverV4:
        """"""
        pass
    @property
    def popular_top_entrance(self) -> bilibili.app.card.v1.single_pb2.PopularTopEntrance:
        """热门列表顶部按钮"""
        pass
    @property
    def rcmd_one_item(self) -> bilibili.app.card.v1.single_pb2.RcmdOneItem:
        """"""
        pass
    def __init__(self,
        *,
        small_cover_v5: typing.Optional[bilibili.app.card.v1.single_pb2.SmallCoverV5] = ...,
        large_cover_v1: typing.Optional[bilibili.app.card.v1.single_pb2.LargeCoverV1] = ...,
        three_item_all_v2: typing.Optional[bilibili.app.card.v1.single_pb2.ThreeItemAllV2] = ...,
        three_item_v1: typing.Optional[bilibili.app.card.v1.single_pb2.ThreeItemV1] = ...,
        hot_topic: typing.Optional[bilibili.app.card.v1.single_pb2.HotTopic] = ...,
        three_item_h_v5: typing.Optional[bilibili.app.card.v1.single_pb2.DynamicHot] = ...,
        middle_cover_v3: typing.Optional[bilibili.app.card.v1.single_pb2.MiddleCoverV3] = ...,
        large_cover_v4: typing.Optional[bilibili.app.card.v1.single_pb2.LargeCoverV4] = ...,
        popular_top_entrance: typing.Optional[bilibili.app.card.v1.single_pb2.PopularTopEntrance] = ...,
        rcmd_one_item: typing.Optional[bilibili.app.card.v1.single_pb2.RcmdOneItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hot_topic",b"hot_topic","item",b"item","large_cover_v1",b"large_cover_v1","large_cover_v4",b"large_cover_v4","middle_cover_v3",b"middle_cover_v3","popular_top_entrance",b"popular_top_entrance","rcmd_one_item",b"rcmd_one_item","small_cover_v5",b"small_cover_v5","three_item_all_v2",b"three_item_all_v2","three_item_h_v5",b"three_item_h_v5","three_item_v1",b"three_item_v1"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hot_topic",b"hot_topic","item",b"item","large_cover_v1",b"large_cover_v1","large_cover_v4",b"large_cover_v4","middle_cover_v3",b"middle_cover_v3","popular_top_entrance",b"popular_top_entrance","rcmd_one_item",b"rcmd_one_item","small_cover_v5",b"small_cover_v5","three_item_all_v2",b"three_item_all_v2","three_item_h_v5",b"three_item_h_v5","three_item_v1",b"three_item_v1"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item",b"item"]) -> typing.Optional[typing_extensions.Literal["small_cover_v5","large_cover_v1","three_item_all_v2","three_item_v1","hot_topic","three_item_h_v5","middle_cover_v3","large_cover_v4","popular_top_entrance","rcmd_one_item"]]: ...
global___Card = Card



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PrivacyConfigState:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PrivacyConfigStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PrivacyConfigState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    close: _PrivacyConfigState.ValueType  # 0
    """关闭"""

    open: _PrivacyConfigState.ValueType  # 1
    """打开"""

class PrivacyConfigState(_PrivacyConfigState, metaclass=_PrivacyConfigStateEnumTypeWrapper):
    """隐私开关状态"""
    pass

close: PrivacyConfigState.ValueType  # 0
"""关闭"""

open: PrivacyConfigState.ValueType  # 1
"""打开"""

global___PrivacyConfigState = PrivacyConfigState


class _PrivacyConfigType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PrivacyConfigTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PrivacyConfigType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    none: _PrivacyConfigType.ValueType  # 0
    """"""

    dynamic_city: _PrivacyConfigType.ValueType  # 1
    """动态同城"""

class PrivacyConfigType(_PrivacyConfigType, metaclass=_PrivacyConfigTypeEnumTypeWrapper):
    """隐私开关类型"""
    pass

none: PrivacyConfigType.ValueType  # 0
""""""

dynamic_city: PrivacyConfigType.ValueType  # 1
"""动态同城"""

global___PrivacyConfigType = PrivacyConfigType


class NoArgRequest(google.protobuf.message.Message):
    """空请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___NoArgRequest = NoArgRequest

class NoReply(google.protobuf.message.Message):
    """空响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___NoReply = NoReply

class PrivacyConfigItem(google.protobuf.message.Message):
    """隐私设置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRIVACY_CONFIG_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_URI_FIELD_NUMBER: builtins.int
    privacy_config_type: global___PrivacyConfigType.ValueType
    """隐私开关类型"""

    title: typing.Text
    """"""

    state: global___PrivacyConfigState.ValueType
    """隐私开关状态"""

    sub_title: typing.Text
    """"""

    sub_title_uri: typing.Text
    """"""

    def __init__(self,
        *,
        privacy_config_type: global___PrivacyConfigType.ValueType = ...,
        title: typing.Text = ...,
        state: global___PrivacyConfigState.ValueType = ...,
        sub_title: typing.Text = ...,
        sub_title_uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy_config_type",b"privacy_config_type","state",b"state","sub_title",b"sub_title","sub_title_uri",b"sub_title_uri","title",b"title"]) -> None: ...
global___PrivacyConfigItem = PrivacyConfigItem

class PrivacyConfigReply(google.protobuf.message.Message):
    """获取隐私设置-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRIVACY_CONFIG_ITEM_FIELD_NUMBER: builtins.int
    @property
    def privacy_config_item(self) -> global___PrivacyConfigItem:
        """隐私设置"""
        pass
    def __init__(self,
        *,
        privacy_config_item: typing.Optional[global___PrivacyConfigItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["privacy_config_item",b"privacy_config_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy_config_item",b"privacy_config_item"]) -> None: ...
global___PrivacyConfigReply = PrivacyConfigReply

class SetPrivacyConfigRequest(google.protobuf.message.Message):
    """修改隐私设置-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRIVACY_CONFIG_TYPE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    privacy_config_type: global___PrivacyConfigType.ValueType
    """隐私开关类型"""

    state: global___PrivacyConfigState.ValueType
    """隐私开关状态"""

    def __init__(self,
        *,
        privacy_config_type: global___PrivacyConfigType.ValueType = ...,
        state: global___PrivacyConfigState.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy_config_type",b"privacy_config_type","state",b"state"]) -> None: ...
global___SetPrivacyConfigRequest = SetPrivacyConfigRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/ogv/live.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/broadcast/message/ogv/live.proto\x12\x1e\x62ilibili.broadcast.message.ogv\"\x10\n\x0eLiveStartEvent\"\x0e\n\x0cLiveEndEvent\"!\n\x0fLiveOnlineEvent\x12\x0e\n\x06online\x18\x01 \x01(\x03\"`\n\x0fLiveUpdateEvent\x12\x1b\n\x13\x61\x66ter_premiere_type\x18\x01 \x01(\x05\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08progress\x18\x04 \x01(\x03\"\x9c\x02\n\x07\x43MDBody\x12?\n\x05start\x18\x01 \x01(\x0b\x32..bilibili.broadcast.message.ogv.LiveStartEventH\x00\x12\x41\n\temergency\x18\x02 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.LiveEndEventH\x00\x12\x41\n\x06online\x18\x03 \x01(\x0b\x32/.bilibili.broadcast.message.ogv.LiveOnlineEventH\x00\x12\x41\n\x06update\x18\x04 \x01(\x0b\x32/.bilibili.broadcast.message.ogv.LiveUpdateEventH\x00\x42\x07\n\x05\x65ventb\x06proto3')



_LIVESTARTEVENT = DESCRIPTOR.message_types_by_name['LiveStartEvent']
_LIVEENDEVENT = DESCRIPTOR.message_types_by_name['LiveEndEvent']
_LIVEONLINEEVENT = DESCRIPTOR.message_types_by_name['LiveOnlineEvent']
_LIVEUPDATEEVENT = DESCRIPTOR.message_types_by_name['LiveUpdateEvent']
_CMDBODY = DESCRIPTOR.message_types_by_name['CMDBody']
LiveStartEvent = _reflection.GeneratedProtocolMessageType('LiveStartEvent', (_message.Message,), {
  'DESCRIPTOR' : _LIVESTARTEVENT,
  '__module__' : 'bilibili.broadcast.message.ogv.live_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.ogv.LiveStartEvent)
  })
_sym_db.RegisterMessage(LiveStartEvent)

LiveEndEvent = _reflection.GeneratedProtocolMessageType('LiveEndEvent', (_message.Message,), {
  'DESCRIPTOR' : _LIVEENDEVENT,
  '__module__' : 'bilibili.broadcast.message.ogv.live_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.ogv.LiveEndEvent)
  })
_sym_db.RegisterMessage(LiveEndEvent)

LiveOnlineEvent = _reflection.GeneratedProtocolMessageType('LiveOnlineEvent', (_message.Message,), {
  'DESCRIPTOR' : _LIVEONLINEEVENT,
  '__module__' : 'bilibili.broadcast.message.ogv.live_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.ogv.LiveOnlineEvent)
  })
_sym_db.RegisterMessage(LiveOnlineEvent)

LiveUpdateEvent = _reflection.GeneratedProtocolMessageType('LiveUpdateEvent', (_message.Message,), {
  'DESCRIPTOR' : _LIVEUPDATEEVENT,
  '__module__' : 'bilibili.broadcast.message.ogv.live_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.ogv.LiveUpdateEvent)
  })
_sym_db.RegisterMessage(LiveUpdateEvent)

CMDBody = _reflection.GeneratedProtocolMessageType('CMDBody', (_message.Message,), {
  'DESCRIPTOR' : _CMDBODY,
  '__module__' : 'bilibili.broadcast.message.ogv.live_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.ogv.CMDBody)
  })
_sym_db.RegisterMessage(CMDBody)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIVESTARTEVENT._serialized_start=77
  _LIVESTARTEVENT._serialized_end=93
  _LIVEENDEVENT._serialized_start=95
  _LIVEENDEVENT._serialized_end=109
  _LIVEONLINEEVENT._serialized_start=111
  _LIVEONLINEEVENT._serialized_end=144
  _LIVEUPDATEEVENT._serialized_start=146
  _LIVEUPDATEEVENT._serialized_end=242
  _CMDBODY._serialized_start=245
  _CMDBODY._serialized_end=529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/tv/interfaces/dm/v1/dm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/tv/interfaces/dm/v1/dm.proto\x12\x1c\x62ilibili.tv.interfaces.dm.v1\"\xc2\x01\n\x0c\x43ommandDmOtt\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x05 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x10\n\x08progress\x18\x08 \x01(\x05\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\r\n\x05\x65xtra\x18\x0b \x01(\t\x12\x0e\n\x06id_str\x18\x0c \x01(\t\"Y\n\x12\x43ommandDmsOttReply\x12\x43\n\x0f\x63ommand_dms_ott\x18\x01 \x03(\x0b\x32*.bilibili.tv.interfaces.dm.v1.CommandDmOtt\"9\n\x10\x43ommandDmsOttReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\"L\n\rDanmakuAIFlag\x12;\n\x08\x64m_flags\x18\x01 \x03(\x0b\x32).bilibili.tv.interfaces.dm.v1.DanmakuFlag\"\xd6\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x0f\n\x07midHash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06weight\x18\t \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\n \x01(\t\x12\x0c\n\x04pool\x18\x0b \x01(\x05\x12\r\n\x05idStr\x18\x0c \x01(\t\x12\x0c\n\x04\x61ttr\x18\r \x01(\x05\")\n\x0b\x44\x61nmakuFlag\x12\x0c\n\x04\x64mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\"K\n\x11\x44\x61nmakuFlagConfig\x12\x10\n\x08rec_flag\x18\x01 \x01(\x05\x12\x10\n\x08rec_text\x18\x02 \x01(\t\x12\x12\n\nrec_switch\x18\x03 \x01(\x05\"\xcc\x04\n\x18\x44\x61nmuDefaultPlayerConfig\x12)\n!player_danmaku_use_default_config\x18\x01 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12$\n\x1cinline_player_danmaku_switch\x18\x10 \x01(\x08\x12)\n!player_danmaku_senior_mode_switch\x18\x11 \x01(\x05\"\xd3\x05\n\x11\x44\x61nmuPlayerConfig\x12\x1d\n\x15player_danmaku_switch\x18\x01 \x01(\x08\x12\"\n\x1aplayer_danmaku_switch_save\x18\x02 \x01(\x08\x12)\n!player_danmaku_use_default_config\x18\x03 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12&\n\x1eplayer_danmaku_enableblocklist\x18\x10 \x01(\x08\x12$\n\x1cinline_player_danmaku_switch\x18\x11 \x01(\x08\x12$\n\x1cinline_player_danmaku_config\x18\x12 \x01(\x05\x12&\n\x1eplayer_danmaku_ios_switch_save\x18\x13 \x01(\x05\"K\n\x18\x44\x61nmuPlayerDynamicConfig\x12\x10\n\x08progress\x18\x01 \x01(\x05\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\"\xa5\x02\n\x15\x44\x61nmuPlayerViewConfig\x12]\n\x1d\x64\x61nmuku_default_player_config\x18\x01 \x01(\x0b\x32\x36.bilibili.tv.interfaces.dm.v1.DanmuDefaultPlayerConfig\x12N\n\x15\x64\x61nmuku_player_config\x18\x02 \x01(\x0b\x32/.bilibili.tv.interfaces.dm.v1.DanmuPlayerConfig\x12]\n\x1d\x64\x61nmuku_player_dynamic_config\x18\x03 \x03(\x0b\x32\x36.bilibili.tv.interfaces.dm.v1.DanmuPlayerDynamicConfig\"\x99\x01\n\x10\x44mSegMobileReply\x12\x38\n\x05\x65lems\x18\x01 \x03(\x0b\x32).bilibili.tv.interfaces.dm.v1.DanmakuElem\x12\r\n\x05state\x18\x02 \x01(\x05\x12<\n\x07\x61i_flag\x18\x03 \x01(\x0b\x32+.bilibili.tv.interfaces.dm.v1.DanmakuAIFlag\"u\n\x0e\x44mSegMobileReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\x12\x16\n\x0eteenagers_mode\x18\x05 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x06 \x01(\x03\"\xc1\x03\n\x0b\x44mViewReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12\x35\n\x04mask\x18\x02 \x01(\x0b\x32\'.bilibili.tv.interfaces.dm.v1.VideoMask\x12=\n\x08subtitle\x18\x03 \x01(\x0b\x32+.bilibili.tv.interfaces.dm.v1.VideoSubtitle\x12\x13\n\x0bspecial_dms\x18\x04 \x03(\t\x12@\n\x07\x61i_flag\x18\x05 \x01(\x0b\x32/.bilibili.tv.interfaces.dm.v1.DanmakuFlagConfig\x12J\n\rplayer_config\x18\x06 \x01(\x0b\x32\x33.bilibili.tv.interfaces.dm.v1.DanmuPlayerViewConfig\x12\x16\n\x0esend_box_style\x18\x07 \x01(\x05\x12\r\n\x05\x61llow\x18\x08 \x01(\x08\x12\x11\n\tcheck_box\x18\t \x01(\t\x12\x1a\n\x12\x63heck_box_show_msg\x18\n \x01(\t\x12\x18\n\x10text_placeholder\x18\x0b \x01(\t\x12\x19\n\x11input_placeholder\x18\x0c \x01(\t\"f\n\tDmViewReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x14\n\x0cis_hard_boot\x18\x05 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x06 \x01(\x03\"\x96\x01\n\x0cSubtitleItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06id_str\x18\x02 \x01(\t\x12\x0b\n\x03lan\x18\x03 \x01(\t\x12\x0f\n\x07lan_doc\x18\x04 \x01(\t\x12\x14\n\x0csubtitle_url\x18\x05 \x01(\t\x12\x36\n\x06\x61uthor\x18\x06 \x01(\x0b\x32&.bilibili.tv.interfaces.dm.v1.UserInfo\"\\\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x0c\n\x04rank\x18\x06 \x01(\x05\"S\n\tVideoMask\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04plat\x18\x02 \x01(\x05\x12\x0b\n\x03\x66ps\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x03\x12\x10\n\x08mask_url\x18\x05 \x01(\t\"k\n\rVideoSubtitle\x12\x0b\n\x03lan\x18\x01 \x01(\t\x12\x0e\n\x06lanDoc\x18\x02 \x01(\t\x12=\n\tsubtitles\x18\x03 \x03(\x0b\x32*.bilibili.tv.interfaces.dm.v1.SubtitleItemb\x06proto3')



_COMMANDDMOTT = DESCRIPTOR.message_types_by_name['CommandDmOtt']
_COMMANDDMSOTTREPLY = DESCRIPTOR.message_types_by_name['CommandDmsOttReply']
_COMMANDDMSOTTREQ = DESCRIPTOR.message_types_by_name['CommandDmsOttReq']
_DANMAKUAIFLAG = DESCRIPTOR.message_types_by_name['DanmakuAIFlag']
_DANMAKUELEM = DESCRIPTOR.message_types_by_name['DanmakuElem']
_DANMAKUFLAG = DESCRIPTOR.message_types_by_name['DanmakuFlag']
_DANMAKUFLAGCONFIG = DESCRIPTOR.message_types_by_name['DanmakuFlagConfig']
_DANMUDEFAULTPLAYERCONFIG = DESCRIPTOR.message_types_by_name['DanmuDefaultPlayerConfig']
_DANMUPLAYERCONFIG = DESCRIPTOR.message_types_by_name['DanmuPlayerConfig']
_DANMUPLAYERDYNAMICCONFIG = DESCRIPTOR.message_types_by_name['DanmuPlayerDynamicConfig']
_DANMUPLAYERVIEWCONFIG = DESCRIPTOR.message_types_by_name['DanmuPlayerViewConfig']
_DMSEGMOBILEREPLY = DESCRIPTOR.message_types_by_name['DmSegMobileReply']
_DMSEGMOBILEREQ = DESCRIPTOR.message_types_by_name['DmSegMobileReq']
_DMVIEWREPLY = DESCRIPTOR.message_types_by_name['DmViewReply']
_DMVIEWREQ = DESCRIPTOR.message_types_by_name['DmViewReq']
_SUBTITLEITEM = DESCRIPTOR.message_types_by_name['SubtitleItem']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_VIDEOMASK = DESCRIPTOR.message_types_by_name['VideoMask']
_VIDEOSUBTITLE = DESCRIPTOR.message_types_by_name['VideoSubtitle']
CommandDmOtt = _reflection.GeneratedProtocolMessageType('CommandDmOtt', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDMOTT,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.CommandDmOtt)
  })
_sym_db.RegisterMessage(CommandDmOtt)

CommandDmsOttReply = _reflection.GeneratedProtocolMessageType('CommandDmsOttReply', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDMSOTTREPLY,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.CommandDmsOttReply)
  })
_sym_db.RegisterMessage(CommandDmsOttReply)

CommandDmsOttReq = _reflection.GeneratedProtocolMessageType('CommandDmsOttReq', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDMSOTTREQ,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.CommandDmsOttReq)
  })
_sym_db.RegisterMessage(CommandDmsOttReq)

DanmakuAIFlag = _reflection.GeneratedProtocolMessageType('DanmakuAIFlag', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUAIFLAG,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmakuAIFlag)
  })
_sym_db.RegisterMessage(DanmakuAIFlag)

DanmakuElem = _reflection.GeneratedProtocolMessageType('DanmakuElem', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUELEM,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmakuElem)
  })
_sym_db.RegisterMessage(DanmakuElem)

DanmakuFlag = _reflection.GeneratedProtocolMessageType('DanmakuFlag', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUFLAG,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmakuFlag)
  })
_sym_db.RegisterMessage(DanmakuFlag)

DanmakuFlagConfig = _reflection.GeneratedProtocolMessageType('DanmakuFlagConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMAKUFLAGCONFIG,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmakuFlagConfig)
  })
_sym_db.RegisterMessage(DanmakuFlagConfig)

DanmuDefaultPlayerConfig = _reflection.GeneratedProtocolMessageType('DanmuDefaultPlayerConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUDEFAULTPLAYERCONFIG,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmuDefaultPlayerConfig)
  })
_sym_db.RegisterMessage(DanmuDefaultPlayerConfig)

DanmuPlayerConfig = _reflection.GeneratedProtocolMessageType('DanmuPlayerConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUPLAYERCONFIG,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmuPlayerConfig)
  })
_sym_db.RegisterMessage(DanmuPlayerConfig)

DanmuPlayerDynamicConfig = _reflection.GeneratedProtocolMessageType('DanmuPlayerDynamicConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUPLAYERDYNAMICCONFIG,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmuPlayerDynamicConfig)
  })
_sym_db.RegisterMessage(DanmuPlayerDynamicConfig)

DanmuPlayerViewConfig = _reflection.GeneratedProtocolMessageType('DanmuPlayerViewConfig', (_message.Message,), {
  'DESCRIPTOR' : _DANMUPLAYERVIEWCONFIG,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DanmuPlayerViewConfig)
  })
_sym_db.RegisterMessage(DanmuPlayerViewConfig)

DmSegMobileReply = _reflection.GeneratedProtocolMessageType('DmSegMobileReply', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGMOBILEREPLY,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DmSegMobileReply)
  })
_sym_db.RegisterMessage(DmSegMobileReply)

DmSegMobileReq = _reflection.GeneratedProtocolMessageType('DmSegMobileReq', (_message.Message,), {
  'DESCRIPTOR' : _DMSEGMOBILEREQ,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DmSegMobileReq)
  })
_sym_db.RegisterMessage(DmSegMobileReq)

DmViewReply = _reflection.GeneratedProtocolMessageType('DmViewReply', (_message.Message,), {
  'DESCRIPTOR' : _DMVIEWREPLY,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DmViewReply)
  })
_sym_db.RegisterMessage(DmViewReply)

DmViewReq = _reflection.GeneratedProtocolMessageType('DmViewReq', (_message.Message,), {
  'DESCRIPTOR' : _DMVIEWREQ,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.DmViewReq)
  })
_sym_db.RegisterMessage(DmViewReq)

SubtitleItem = _reflection.GeneratedProtocolMessageType('SubtitleItem', (_message.Message,), {
  'DESCRIPTOR' : _SUBTITLEITEM,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.SubtitleItem)
  })
_sym_db.RegisterMessage(SubtitleItem)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

VideoMask = _reflection.GeneratedProtocolMessageType('VideoMask', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOMASK,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.VideoMask)
  })
_sym_db.RegisterMessage(VideoMask)

VideoSubtitle = _reflection.GeneratedProtocolMessageType('VideoSubtitle', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOSUBTITLE,
  '__module__' : 'bilibili.tv.interfaces.dm.v1.dm_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.tv.interfaces.dm.v1.VideoSubtitle)
  })
_sym_db.RegisterMessage(VideoSubtitle)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMANDDMOTT._serialized_start=72
  _COMMANDDMOTT._serialized_end=266
  _COMMANDDMSOTTREPLY._serialized_start=268
  _COMMANDDMSOTTREPLY._serialized_end=357
  _COMMANDDMSOTTREQ._serialized_start=359
  _COMMANDDMSOTTREQ._serialized_end=416
  _DANMAKUAIFLAG._serialized_start=418
  _DANMAKUAIFLAG._serialized_end=494
  _DANMAKUELEM._serialized_start=497
  _DANMAKUELEM._serialized_end=711
  _DANMAKUFLAG._serialized_start=713
  _DANMAKUFLAG._serialized_end=754
  _DANMAKUFLAGCONFIG._serialized_start=756
  _DANMAKUFLAGCONFIG._serialized_end=831
  _DANMUDEFAULTPLAYERCONFIG._serialized_start=834
  _DANMUDEFAULTPLAYERCONFIG._serialized_end=1422
  _DANMUPLAYERCONFIG._serialized_start=1425
  _DANMUPLAYERCONFIG._serialized_end=2148
  _DANMUPLAYERDYNAMICCONFIG._serialized_start=2150
  _DANMUPLAYERDYNAMICCONFIG._serialized_end=2225
  _DANMUPLAYERVIEWCONFIG._serialized_start=2228
  _DANMUPLAYERVIEWCONFIG._serialized_end=2521
  _DMSEGMOBILEREPLY._serialized_start=2524
  _DMSEGMOBILEREPLY._serialized_end=2677
  _DMSEGMOBILEREQ._serialized_start=2679
  _DMSEGMOBILEREQ._serialized_end=2796
  _DMVIEWREPLY._serialized_start=2799
  _DMVIEWREPLY._serialized_end=3248
  _DMVIEWREQ._serialized_start=3250
  _DMVIEWREQ._serialized_end=3352
  _SUBTITLEITEM._serialized_start=3355
  _SUBTITLEITEM._serialized_end=3505
  _USERINFO._serialized_start=3507
  _USERINFO._serialized_end=3599
  _VIDEOMASK._serialized_start=3601
  _VIDEOMASK._serialized_end=3684
  _VIDEOSUBTITLE._serialized_start=3686
  _VIDEOSUBTITLE._serialized_end=3793
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RoomProto(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    @property
    def room_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """"""
        pass
    def __init__(self,
        *,
        room_id: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id",b"room_id"]) -> None: ...
global___RoomProto = RoomProto



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class HelloWorldReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    content: typing.Text
    """"""

    def __init__(self,
        *,
        content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content"]) -> None: ...
global___HelloWorldReq = HelloWorldReq

class HelloWorldResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_FIELD_NUMBER: builtins.int
    data: typing.Text
    """"""

    def __init__(self,
        *,
        data: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data"]) -> None: ...
global___HelloWorldResp = HelloWorldResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SuggestionResult3Req(google.protobuf.message.Message):
    """获取搜索建议-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    KEYWORD_FIELD_NUMBER: builtins.int
    HIGHLIGHT_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    keyword: typing.Text
    """关键字"""

    highlight: builtins.int
    """是否语法高亮
    0:不显示 1:显示
    """

    teenagers_mode: builtins.int
    """是否青少年模式
    1:开启青少年模式
    """

    def __init__(self,
        *,
        keyword: typing.Text = ...,
        highlight: builtins.int = ...,
        teenagers_mode: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["highlight",b"highlight","keyword",b"keyword","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___SuggestionResult3Req = SuggestionResult3Req

class SuggestionResult3Reply(google.protobuf.message.Message):
    """获取搜索建议-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRACKID_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    EXPSTR_FIELD_NUMBER: builtins.int
    trackid: typing.Text
    """搜索追踪id"""

    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResultItem]:
        """搜索建议条目列表"""
        pass
    expStr: typing.Text
    """搜索的abtest 实验信息"""

    def __init__(self,
        *,
        trackid: typing.Text = ...,
        list: typing.Optional[typing.Iterable[global___ResultItem]] = ...,
        expStr: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expStr",b"expStr","list",b"list","trackid",b"trackid"]) -> None: ...
global___SuggestionResult3Reply = SuggestionResult3Reply

class ResultItem(google.protobuf.message.Message):
    """搜索建议条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FROM_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_SIZE_FIELD_NUMBER: builtins.int
    SUG_TYPE_FIELD_NUMBER: builtins.int
    TERM_TYPE_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    ARCHIVES_FIELD_NUMBER: builtins.int
    PTIME_FIELD_NUMBER: builtins.int
    SEASON_TYPE_NAME_FIELD_NUMBER: builtins.int
    AREA_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    STYLES_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    title: typing.Text
    """显示结果(语法高亮)"""

    keyword: typing.Text
    """搜索关键字"""

    position: builtins.int
    """序号"""

    cover: typing.Text
    """图片"""

    cover_size: builtins.float
    """图片尺寸"""

    sug_type: typing.Text
    """sug词类型"""

    term_type: builtins.int
    """词条大类型"""

    goto: typing.Text
    """跳转类型"""

    uri: typing.Text
    """跳转uri"""

    @property
    def official_verify(self) -> global___OfficialVerify:
        """认证信息"""
        pass
    param: typing.Text
    """跳转参数"""

    mid: builtins.int
    """up主mid"""

    fans: builtins.int
    """粉丝数"""

    level: builtins.int
    """up主等级"""

    archives: builtins.int
    """up主稿件数"""

    ptime: builtins.int
    """投稿时间"""

    season_type_name: typing.Text
    """season类型名称"""

    area: typing.Text
    """地区"""

    style: typing.Text
    """作品风格"""

    label: typing.Text
    """描述信息"""

    rating: builtins.float
    """评分"""

    vote: builtins.int
    """投票数"""

    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """角标"""
        pass
    styles: typing.Text
    """"""

    module_id: builtins.int
    """"""

    live_link: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        keyword: typing.Text = ...,
        position: builtins.int = ...,
        cover: typing.Text = ...,
        cover_size: builtins.float = ...,
        sug_type: typing.Text = ...,
        term_type: builtins.int = ...,
        goto: typing.Text = ...,
        uri: typing.Text = ...,
        official_verify: typing.Optional[global___OfficialVerify] = ...,
        param: typing.Text = ...,
        mid: builtins.int = ...,
        fans: builtins.int = ...,
        level: builtins.int = ...,
        archives: builtins.int = ...,
        ptime: builtins.int = ...,
        season_type_name: typing.Text = ...,
        area: typing.Text = ...,
        style: typing.Text = ...,
        label: typing.Text = ...,
        rating: builtins.float = ...,
        vote: builtins.int = ...,
        badges: typing.Optional[typing.Iterable[global___ReasonStyle]] = ...,
        styles: typing.Text = ...,
        module_id: builtins.int = ...,
        live_link: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official_verify",b"official_verify"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archives",b"archives","area",b"area","badges",b"badges","cover",b"cover","cover_size",b"cover_size","fans",b"fans","from",b"from","goto",b"goto","keyword",b"keyword","label",b"label","level",b"level","live_link",b"live_link","mid",b"mid","module_id",b"module_id","official_verify",b"official_verify","param",b"param","position",b"position","ptime",b"ptime","rating",b"rating","season_type_name",b"season_type_name","style",b"style","styles",b"styles","sug_type",b"sug_type","term_type",b"term_type","title",b"title","uri",b"uri","vote",b"vote"]) -> None: ...
global___ResultItem = ResultItem

class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    127:未认证 0:个人 1:机构
    """

    desc: typing.Text
    """认证描述"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","type",b"type"]) -> None: ...
global___OfficialVerify = OfficialVerify

class ReasonStyle(google.protobuf.message.Message):
    """角标"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: typing.Text
    """角标文案"""

    text_color: typing.Text
    """文案日间色值"""

    text_color_night: typing.Text
    """文案夜间色值"""

    bg_color: typing.Text
    """背景日间色值"""

    bg_color_night: typing.Text
    """背景夜间色值"""

    border_color: typing.Text
    """边框日间色值"""

    border_color_night: typing.Text
    """边框夜间色值"""

    bg_style: builtins.int
    """角标样式
    1:填充模式 2:镂空模式
    """

    def __init__(self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_night: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        border_color: typing.Text = ...,
        border_color_night: typing.Text = ...,
        bg_style: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","bg_style",b"bg_style","border_color",b"border_color","border_color_night",b"border_color_night","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night"]) -> None: ...
global___ReasonStyle = ReasonStyle



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MessagePullsReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    HAS_NEXT_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """"""
        pass
    pn: builtins.int
    """"""

    ps: builtins.int
    """"""

    count: builtins.int
    """"""

    has_next: builtins.bool
    """"""

    def __init__(self,
        *,
        data: typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        count: builtins.int = ...,
        has_next: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count",b"count","data",b"data","has_next",b"has_next","pn",b"pn","ps",b"ps"]) -> None: ...
global___MessagePullsReply = MessagePullsReply

class MessagePullsReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_SEQ_ID_FIELD_NUMBER: builtins.int
    END_SEQ_ID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    start_seq_id: builtins.int
    """"""

    end_seq_id: builtins.int
    """"""

    pn: builtins.int
    """"""

    ps: builtins.int
    """"""

    def __init__(self,
        *,
        start_seq_id: builtins.int = ...,
        end_seq_id: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_seq_id",b"end_seq_id","pn",b"pn","ps",b"ps","start_seq_id",b"start_seq_id"]) -> None: ...
global___MessagePullsReq = MessagePullsReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PlayStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PlayStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Pause: _PlayStatus.ValueType  # 0
    """暂停"""

    Play: _PlayStatus.ValueType  # 1
    """播放"""

    End: _PlayStatus.ValueType  # 2
    """终止"""

class PlayStatus(_PlayStatus, metaclass=_PlayStatusEnumTypeWrapper):
    """播放状态"""
    pass

Pause: PlayStatus.ValueType  # 0
"""暂停"""

Play: PlayStatus.ValueType  # 1
"""播放"""

End: PlayStatus.ValueType  # 2
"""终止"""

global___PlayStatus = PlayStatus


class _RoomType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _RoomTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RoomType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Private: _RoomType.ValueType  # 0
    """私密"""

    Open: _RoomType.ValueType  # 1
    """公开"""

class RoomType(_RoomType, metaclass=_RoomTypeEnumTypeWrapper):
    """房间类型"""
    pass

Private: RoomType.ValueType  # 0
"""私密"""

Open: RoomType.ValueType  # 1
"""公开"""

global___RoomType = RoomType


class _MessageDomain:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _MessageDomainEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MessageDomain.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultDomain: _MessageDomain.ValueType  # 0
    """默认"""

    RoomMid: _MessageDomain.ValueType  # 1
    """房间用户"""

    SystemInfo: _MessageDomain.ValueType  # 2
    """系统通知"""

class MessageDomain(_MessageDomain, metaclass=_MessageDomainEnumTypeWrapper):
    """信息通知发送领域"""
    pass

DefaultDomain: MessageDomain.ValueType  # 0
"""默认"""

RoomMid: MessageDomain.ValueType  # 1
"""房间用户"""

SystemInfo: MessageDomain.ValueType  # 2
"""系统通知"""

global___MessageDomain = MessageDomain


class _MessageType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _MessageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MessageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultType: _MessageType.ValueType  # 0
    """默认"""

    ChatMessage: _MessageType.ValueType  # 1
    """房间用户"""

    SystemMessage: _MessageType.ValueType  # 2
    """系统通知"""

class MessageType(_MessageType, metaclass=_MessageTypeEnumTypeWrapper):
    """通知信息类型"""
    pass

DefaultType: MessageType.ValueType  # 0
"""默认"""

ChatMessage: MessageType.ValueType  # 1
"""房间用户"""

SystemMessage: MessageType.ValueType  # 2
"""系统通知"""

global___MessageType = MessageType


class _TriggerType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _TriggerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultTrigger: _TriggerType.ValueType  # 0
    """默认"""

    Relation: _TriggerType.ValueType  # 1
    """关注、取消关注"""

class TriggerType(_TriggerType, metaclass=_TriggerTypeEnumTypeWrapper):
    """触发通知类型"""
    pass

DefaultTrigger: TriggerType.ValueType  # 0
"""默认"""

Relation: TriggerType.ValueType  # 1
"""关注、取消关注"""

global___TriggerType = TriggerType


class RoomMemberChangeEvent(google.protobuf.message.Message):
    """房间人员变更事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    OWNER_ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""

    owner_id: builtins.int
    """房主id"""

    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserInfoProto]:
        """房间成员列表"""
        pass
    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
        pass
    def __init__(self,
        *,
        room_id: builtins.int = ...,
        owner_id: builtins.int = ...,
        members: typing.Optional[typing.Iterable[global___UserInfoProto]] = ...,
        message: typing.Optional[global___MessageProto] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["members",b"members","message",b"message","owner_id",b"owner_id","room_id",b"room_id"]) -> None: ...
global___RoomMemberChangeEvent = RoomMemberChangeEvent

class ProgressSyncEvent(google.protobuf.message.Message):
    """播放进度同步事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    EPISODE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""

    season_id: builtins.int
    """播放中的season_id"""

    episode_id: builtins.int
    """播放中的episode_id"""

    status: global___PlayStatus.ValueType
    """播放状态"""

    progress: builtins.int
    """房主播放进度"""

    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
        pass
    def __init__(self,
        *,
        room_id: builtins.int = ...,
        season_id: builtins.int = ...,
        episode_id: builtins.int = ...,
        status: global___PlayStatus.ValueType = ...,
        progress: builtins.int = ...,
        message: typing.Optional[global___MessageProto] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["episode_id",b"episode_id","message",b"message","progress",b"progress","room_id",b"room_id","season_id",b"season_id","status",b"status"]) -> None: ...
global___ProgressSyncEvent = ProgressSyncEvent

class RoomUpdateEvent(google.protobuf.message.Message):
    """房间状态更新"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""

    type: global___RoomType.ValueType
    """房间变更状态"""

    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
        pass
    def __init__(self,
        *,
        room_id: builtins.int = ...,
        type: global___RoomType.ValueType = ...,
        message: typing.Optional[global___MessageProto] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message",b"message","room_id",b"room_id","type",b"type"]) -> None: ...
global___RoomUpdateEvent = RoomUpdateEvent

class RoomDestroyEvent(google.protobuf.message.Message):
    """房间销毁通知"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""

    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
        pass
    def __init__(self,
        *,
        room_id: builtins.int = ...,
        message: typing.Optional[global___MessageProto] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message",b"message","room_id",b"room_id"]) -> None: ...
global___RoomDestroyEvent = RoomDestroyEvent

class RoomTriggerEvent(google.protobuf.message.Message):
    """房间触发通知"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """操作人"""

    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
        pass
    trigger: global___TriggerType.ValueType
    """触发类型"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        message: typing.Optional[global___MessageProto] = ...,
        trigger: global___TriggerType.ValueType = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message",b"message","mid",b"mid","trigger",b"trigger"]) -> None: ...
global___RoomTriggerEvent = RoomTriggerEvent

class UserInfoProto(google.protobuf.message.Message):
    """用户信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NICKNAME_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户id"""

    face: typing.Text
    """用户头像url"""

    nickname: typing.Text
    """昵称"""

    level: builtins.int
    """等级"""

    sign: typing.Text
    """签名"""

    @property
    def vip(self) -> global___VipProto:
        """大会员信息"""
        pass
    @property
    def official(self) -> global___OfficialProto:
        """身份认证信息"""
        pass
    @property
    def pendant(self) -> global___PendantProto:
        """挂件信息"""
        pass
    buvid: typing.Text
    """设备buvid"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        face: typing.Text = ...,
        nickname: typing.Text = ...,
        level: builtins.int = ...,
        sign: typing.Text = ...,
        vip: typing.Optional[global___VipProto] = ...,
        official: typing.Optional[global___OfficialProto] = ...,
        pendant: typing.Optional[global___PendantProto] = ...,
        buvid: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official",b"official","pendant",b"pendant","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid",b"buvid","face",b"face","level",b"level","mid",b"mid","nickname",b"nickname","official",b"official","pendant",b"pendant","sign",b"sign","vip",b"vip"]) -> None: ...
global___UserInfoProto = UserInfoProto

class MessageProto(google.protobuf.message.Message):
    """通知信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    content: typing.Text
    """可带占位符匹配的消息体 ep "还没有其他小伙伴，[去邀请>]<https://big.bilibili.com/mobile/giftIndex?mid=123>" """

    content_type: builtins.int
    """消息体类型
    0:json格式的文本消息 1:支持全文本可点(破冰)
    """

    def __init__(self,
        *,
        content: typing.Text = ...,
        content_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","content_type",b"content_type"]) -> None: ...
global___MessageProto = MessageProto

class VipProto(google.protobuf.message.Message):
    """大会员信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    VIP_PAY_TYPE_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
    NICKNAME_COLOR_FIELD_NUMBER: builtins.int
    type: builtins.int
    status: builtins.int
    due_date: builtins.int
    vip_pay_type: builtins.int
    theme_type: builtins.int
    avatar_subscript: builtins.int
    """大会员角标
    0:无角标 1:粉色大会员角标 2:绿色小会员角标
    """

    nickname_color: typing.Text
    """昵称色值，可能为空，色值示例：#FFFB9E60"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        status: builtins.int = ...,
        due_date: builtins.int = ...,
        vip_pay_type: builtins.int = ...,
        theme_type: builtins.int = ...,
        avatar_subscript: builtins.int = ...,
        nickname_color: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar_subscript",b"avatar_subscript","due_date",b"due_date","nickname_color",b"nickname_color","status",b"status","theme_type",b"theme_type","type",b"type","vip_pay_type",b"vip_pay_type"]) -> None: ...
global___VipProto = VipProto

class OfficialProto(google.protobuf.message.Message):
    """认证信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    role: builtins.int
    title: typing.Text
    desc: typing.Text
    type: builtins.int
    def __init__(self,
        *,
        role: builtins.int = ...,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","role",b"role","title",b"title","type",b"type"]) -> None: ...
global___OfficialProto = OfficialProto

class PendantProto(google.protobuf.message.Message):
    """挂件信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    IMAGE_ENHANCE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    name: typing.Text
    image: typing.Text
    expire: builtins.int
    image_enhance: typing.Text
    def __init__(self,
        *,
        pid: builtins.int = ...,
        name: typing.Text = ...,
        image: typing.Text = ...,
        expire: builtins.int = ...,
        image_enhance: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire",b"expire","image",b"image","image_enhance",b"image_enhance","name",b"name","pid",b"pid"]) -> None: ...
global___PendantProto = PendantProto

class MessageEvent(google.protobuf.message.Message):
    """通用信息通知"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    MSG_ID_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    MSG_ID2_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""

    msg_id: builtins.int
    """消息id"""

    ts: builtins.int
    """消息发送服务端时间 时间戳 单位秒"""

    oid: builtins.int
    """信息通知发送主体id"""

    domain: global___MessageDomain.ValueType
    """信息通知发送领域"""

    type: global___MessageType.ValueType
    """通知信息类型"""

    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
        pass
    @property
    def user(self) -> global___UserInfoProto:
        """消息发送用户信息"""
        pass
    msg_id2: typing.Text
    """消息id str类型"""

    def __init__(self,
        *,
        room_id: builtins.int = ...,
        msg_id: builtins.int = ...,
        ts: builtins.int = ...,
        oid: builtins.int = ...,
        domain: global___MessageDomain.ValueType = ...,
        type: global___MessageType.ValueType = ...,
        message: typing.Optional[global___MessageProto] = ...,
        user: typing.Optional[global___UserInfoProto] = ...,
        msg_id2: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message","user",b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain",b"domain","message",b"message","msg_id",b"msg_id","msg_id2",b"msg_id2","oid",b"oid","room_id",b"room_id","ts",b"ts","type",b"type","user",b"user"]) -> None: ...
global___MessageEvent = MessageEvent

class RemoveChatEvent(google.protobuf.message.Message):
    """聊天信息清除通知"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    MSG_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""

    msg_id: builtins.int
    """撤回的聊天信息id"""

    @property
    def message(self) -> global___MessageProto:
        """提示信息"""
        pass
    def __init__(self,
        *,
        room_id: builtins.int = ...,
        msg_id: builtins.int = ...,
        message: typing.Optional[global___MessageProto] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message",b"message","msg_id",b"msg_id","room_id",b"room_id"]) -> None: ...
global___RemoveChatEvent = RemoveChatEvent

class FreyaEventBody(google.protobuf.message.Message):
    """"一起看"房间事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    WHITE_MID_FIELD_NUMBER: builtins.int
    IGNORE_MID_FIELD_NUMBER: builtins.int
    MEMBER_CHANGE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    ROOM_UPDATE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REMOVE_CHAT_FIELD_NUMBER: builtins.int
    ROOM_DESTROY_FIELD_NUMBER: builtins.int
    ROOM_TRIGGER_FIELD_NUMBER: builtins.int
    SEQUENCE_ID_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间id"""

    @property
    def white_mid(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """接收事件消息的白名单用户"""
        pass
    @property
    def ignore_mid(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """不处理信息的黑名单用户 优先级低于白名单 当白名单有数据时 忽略黑名单"""
        pass
    @property
    def member_change(self) -> global___RoomMemberChangeEvent:
        """房间人员变更事件"""
        pass
    @property
    def progress(self) -> global___ProgressSyncEvent:
        """播放进度同步事件"""
        pass
    @property
    def room_update(self) -> global___RoomUpdateEvent:
        """房间状态更新"""
        pass
    @property
    def message(self) -> global___MessageEvent:
        """通用信息通知"""
        pass
    @property
    def remove_chat(self) -> global___RemoveChatEvent:
        """聊天信息清除通知"""
        pass
    @property
    def room_destroy(self) -> global___RoomDestroyEvent:
        """房间销毁通知"""
        pass
    @property
    def room_trigger(self) -> global___RoomTriggerEvent:
        """房间触发通知"""
        pass
    sequence_id: builtins.int
    """消息序列号"""

    def __init__(self,
        *,
        room_id: builtins.int = ...,
        white_mid: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ignore_mid: typing.Optional[typing.Iterable[builtins.int]] = ...,
        member_change: typing.Optional[global___RoomMemberChangeEvent] = ...,
        progress: typing.Optional[global___ProgressSyncEvent] = ...,
        room_update: typing.Optional[global___RoomUpdateEvent] = ...,
        message: typing.Optional[global___MessageEvent] = ...,
        remove_chat: typing.Optional[global___RemoveChatEvent] = ...,
        room_destroy: typing.Optional[global___RoomDestroyEvent] = ...,
        room_trigger: typing.Optional[global___RoomTriggerEvent] = ...,
        sequence_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event",b"event","member_change",b"member_change","message",b"message","progress",b"progress","remove_chat",b"remove_chat","room_destroy",b"room_destroy","room_trigger",b"room_trigger","room_update",b"room_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event",b"event","ignore_mid",b"ignore_mid","member_change",b"member_change","message",b"message","progress",b"progress","remove_chat",b"remove_chat","room_destroy",b"room_destroy","room_id",b"room_id","room_trigger",b"room_trigger","room_update",b"room_update","sequence_id",b"sequence_id","white_mid",b"white_mid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event",b"event"]) -> typing.Optional[typing_extensions.Literal["member_change","progress","room_update","message","remove_chat","room_destroy","room_trigger"]]: ...
global___FreyaEventBody = FreyaEventBody



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pgc/biz/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12pgc/biz/room.proto\x12\x07pgc.biz\"\x1c\n\tRoomProto\x12\x0f\n\x07room_id\x18\x01 \x03(\tb\x06proto3')



_ROOMPROTO = DESCRIPTOR.message_types_by_name['RoomProto']
RoomProto = _reflection.GeneratedProtocolMessageType('RoomProto', (_message.Message,), {
  'DESCRIPTOR' : _ROOMPROTO,
  '__module__' : 'pgc.biz.room_pb2'
  # @@protoc_insertion_point(class_scope:pgc.biz.RoomProto)
  })
_sym_db.RegisterMessage(RoomProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROOMPROTO._serialized_start=31
  _ROOMPROTO._serialized_end=59
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/metadata/restriction/restriction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/metadata/restriction/restriction.proto\x12\x1d\x62ilibili.metadata.restriction\"\x98\x01\n\x0bRestriction\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x08\x12\x14\n\x0clessons_mode\x18\x02 \x01(\x08\x12\x35\n\x04mode\x18\x03 \x01(\x0e\x32\'.bilibili.metadata.restriction.ModeType\x12\x0e\n\x06review\x18\x04 \x01(\x08\x12\x14\n\x0c\x64isable_rcmd\x18\x05 \x01(\x08*2\n\x08ModeType\x12\n\n\x06NORMAL\x10\x00\x12\r\n\tTEENAGERS\x10\x01\x12\x0b\n\x07LESSONS\x10\x02\x62\x06proto3')

_MODETYPE = DESCRIPTOR.enum_types_by_name['ModeType']
ModeType = enum_type_wrapper.EnumTypeWrapper(_MODETYPE)
NORMAL = 0
TEENAGERS = 1
LESSONS = 2


_RESTRICTION = DESCRIPTOR.message_types_by_name['Restriction']
Restriction = _reflection.GeneratedProtocolMessageType('Restriction', (_message.Message,), {
  'DESCRIPTOR' : _RESTRICTION,
  '__module__' : 'bilibili.metadata.restriction.restriction_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.metadata.restriction.Restriction)
  })
_sym_db.RegisterMessage(Restriction)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MODETYPE._serialized_start=237
  _MODETYPE._serialized_end=287
  _RESTRICTION._serialized_start=83
  _RESTRICTION._serialized_end=235
# @@protoc_insertion_point(module_scope)
